## 2.0.1 (2022-08-10)

Remove a few unused `TypedDict`s (#8522)

## 2.0.0 (2022-07-28)

Update emoji stubs for v2.0.0 (#8426)

## 1.7.4 (2022-07-19)

Add missing third party modules (#8321)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: hauntsaninja <>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 1.7.3 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 1.7.2 (2022-06-26)

emoji: complete stubs (#8170)

Co-authored-by: hauntsaninja <>

## 1.7.1 (2022-06-10)

Add stub for emoji.is_emoji (#8053)

## 1.7.0 (2022-05-22)

Update emoji stubs for version 1.7 (#7884)

## 1.2.8 (2022-04-27)

Drop Python 2 support from emoji (#7716)

## 1.2.6 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 1.2.5 (2021-10-12)

Add star to all non-0.1 versions (#6146)

